@@ -11,25 +11,24 @@ import matplotlib.pyplot as plt
 import numpy as np
 from psutil import cpu_count
 
-from adcircpy.mesh import AdcircMesh
-from adcircpy.fort15 import Fort15
+from adcircpy._fort15 import _Fort15
 from adcircpy.forcing import Tides  # , Winds
+from adcircpy.mesh import AdcircMesh
 from adcircpy.outputs.collection import OutputCollection
-from adcircpy.server.driver_file import DriverFile
-from adcircpy.server.config import ServerConfig
-from adcircpy.server.slurm import SlurmConfig
+from adcircpy.server import SSHConfig, SlurmConfig
+from adcircpy.server._driver_file import _DriverFile
 
 
-class AdcircRun(Fort15):
+class AdcircRun(_Fort15):
 
     def __init__(
-        self,
-        mesh: AdcircMesh,
-        start_date: datetime,
-        end_date: datetime,
-        spinup_time: timedelta = None,
-        netcdf: bool = True,
-        server_config: Union[int, ServerConfig, SlurmConfig] = None
+            self,
+            mesh: AdcircMesh,
+            start_date: datetime,
+            end_date: datetime,
+            spinup_time: timedelta = None,
+            netcdf: bool = True,
+            server_config: Union[int, SSHConfig, SlurmConfig] = None
     ):
         self._mesh = mesh
         self._start_date = start_date
@@ -39,47 +38,48 @@ class AdcircRun(Fort15):
         self._server_config = server_config
 
     def add_elevation_output_station(
-        self,
-        station_name: str,
-        vertices: np.array  # TODO: Is there a way to be more concise about this? (e.g. specify dimentionality?)
+            self,
+            station_name: str,
+            vertices: np.array
+            # TODO: Is there a way to be more concise about this? (e.g. specify dimentionality?)
     ):
         self._certify_station('elevation', station_name, vertices)
         self._elevation_stations[station_name] = vertices
 
     def add_velocity_output_station(
-        self,
-        station_name: str,
-        vertices: np.array
+            self,
+            station_name: str,
+            vertices: np.array
     ):
         self._certify_station('velocity', station_name, vertices)
         self._velocity_stations[station_name] = vertices
 
     def add_meteorological_output_station(
-        self,
-        station_name: str,
-        vertices: np.array
+            self,
+            station_name: str,
+            vertices: np.array
     ):
         self._certify_station('meteorological', station_name, vertices)
         self._meteorological_stations[station_name] = vertices
 
     def add_concentration_output_station(
-        self,
-        station_name: str,
-        vertices: np.array
+            self,
+            station_name: str,
+            vertices: np.array
     ):
         self._certify_station('concentration', station_name, vertices)
         self._concentration_stations[station_name] = vertices
 
     def set_elevation_stations_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -103,15 +103,15 @@ class AdcircRun(Fort15):
         })
 
     def set_velocity_stations_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -134,15 +134,15 @@ class AdcircRun(Fort15):
         })
 
     def set_meteorological_stations_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -165,15 +165,15 @@ class AdcircRun(Fort15):
         })
 
     def set_concentration_stations_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -196,15 +196,15 @@ class AdcircRun(Fort15):
         })
 
     def set_elevation_surface_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -227,15 +227,15 @@ class AdcircRun(Fort15):
         })
 
     def set_velocity_surface_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -258,15 +258,15 @@ class AdcircRun(Fort15):
         })
 
     def set_meteorological_surface_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -289,15 +289,15 @@ class AdcircRun(Fort15):
         })
 
     def set_concentration_surface_output(
-        self,
-        sampling_rate: timedelta,
-        start: Union[timedelta, int] = None,
-        end: Union[timedelta, int] = None,
-        spinup: Union[timedelta, int] = None,
-        spinup_start: Union[timedelta, int] = None,
-        spinup_end: Union[timedelta, int] = None,
-        netcdf: bool = True,
-        harmonic_analysis: bool = False,
+            self,
+            sampling_rate: timedelta,
+            start: Union[timedelta, int] = None,
+            end: Union[timedelta, int] = None,
+            spinup: Union[timedelta, int] = None,
+            spinup_start: Union[timedelta, int] = None,
+            spinup_end: Union[timedelta, int] = None,
+            netcdf: bool = True,
+            harmonic_analysis: bool = False,
     ):
         self._certify_output_request(
             sampling_rate,
@@ -332,16 +332,16 @@ class AdcircRun(Fort15):
         self._concentration_stations.pop(station_name)
 
     def write(
-        self,
-        output_directory: str,
-        overwrite: bool = False,
-        fort14: str = 'fort.14',
-        fort13: str = 'fort.13',
-        fort22: str = 'fort.22',
-        fort15: str = 'fort.15',
-        coldstart: str = 'fort.15.coldstart',
-        hotstart: str = 'fort.15.hotstart',
-        driver: str = 'driver.sh'
+            self,
+            output_directory: str,
+            overwrite: bool = False,
+            fort14: str = 'fort.14',
+            fort13: str = 'fort.13',
+            fort22: str = 'fort.22',
+            fort15: str = 'fort.15',
+            coldstart: str = 'fort.15.coldstart',
+            hotstart: str = 'fort.15.hotstart',
+            driver: str = 'driver.sh'
     ):
         output_directory = pathlib.Path(output_directory)
         output_directory.mkdir(parents=True, exist_ok=overwrite)
@@ -396,14 +396,14 @@ class AdcircRun(Fort15):
         if isinstance(self._server_config, SlurmConfig):
             driver = self._server_config._filename
         if driver is not None:
-            DriverFile(self).write(
+            _DriverFile(self).write(
                 output_directory / driver
-                )
+            )
 
     def import_stations(self, fort15):
         station_types = ['NOUTE', 'NOUTV', 'NOUTM', 'NOUTC']
         for station_type in station_types:
-            stations = Fort15.parse_stations(fort15, station_type)
+            stations = _Fort15.parse_stations(fort15, station_type)
             for name, vertices in stations.items():
                 if station_type == 'NOUTE':
                     self.add_elevation_output_station(name, vertices)
@@ -415,13 +415,13 @@ class AdcircRun(Fort15):
                     self.add_concentration_output_station(name, vertices)
 
     def run(
-        self,
-        outdir=None,
-        nproc=-1,
-        overwrite=False,
-        coldstart=True,
-        hotstart=True,
-        server_config=None,
+            self,
+            outdir=None,
+            nproc=-1,
+            overwrite=False,
+            coldstart=True,
+            hotstart=True,
+            server_config=None,
     ):
 
         if outdir is None:
@@ -723,15 +723,15 @@ class AdcircRun(Fort15):
         plt.show()
 
     def _certify_output_request(
-        self,
-        sampling_rate: timedelta,
-        start,
-        end,
-        spinup,
-        spinup_start,
-        spinup_end,
-        netcdf,
-        harmonic_analysis,
+            self,
+            sampling_rate: timedelta,
+            start,
+            end,
+            spinup,
+            spinup_start,
+            spinup_end,
+            netcdf,
+            harmonic_analysis,
     ):
         self._certify_sampling_rate(sampling_rate)
         self._certify__OUT__('start', start)
@@ -893,8 +893,8 @@ class AdcircRun(Fort15):
     def _server_config(self, server_config):
         if server_config is None:
             server_config = self._get_nproc(-1)
-        msg = "server_config must be int, ServerConfig or SlurmConfig"
-        assert isinstance(server_config, (int, ServerConfig, SlurmConfig)), msg
+        msg = "server_config must be int, SSHConfig or SlurmConfig"
+        assert isinstance(server_config, (int, SSHConfig, SlurmConfig)), msg
         self.__server_config = server_config
 
     @property
@@ -917,10 +917,10 @@ class AdcircRun(Fort15):
         for otype in ['surface', 'stations']:
             container[otype] = dict()
             for ovar in [
-                    'elevation',
-                    'velocity',
-                    'meteorological',
-                    'concentration']:
+                'elevation',
+                'velocity',
+                'meteorological',
+                'concentration']:
                 container[otype][ovar] = schema.copy()
                 if otype == 'stations':
                     container[otype][ovar].update({'collection': dict()})
