@@ -11,32 +11,32 @@ from mpl_toolkits.axes_grid1 import make_axes_locatable
 import numpy as np
 from shapely.geometry import LineString, mapping
 
-from adcircpy.forcing.bctypes import BoundaryCondition
-from adcircpy.forcing.winds.base import WindForcing
-from adcircpy.mesh import figures as fig, grd, sms2dm
-from adcircpy.mesh.base import EuclideanMesh2D
+from adcircpy.forcing._bctypes import _BoundaryCondition
+from adcircpy.forcing.winds._base import _WindForcing
+from adcircpy.mesh import _figures as fig, grd, sms2dm
+from adcircpy.mesh._base import _EuclideanMesh2D
 
 
-class AdcircMesh(EuclideanMesh2D):
+class AdcircMesh(_EuclideanMesh2D):
     """
     Class that represents the unstructured planar mesh used by ADCIRC.
     """
 
     def __init__(
-          self,
-          nodes,
-          elements,
-          boundaries=None,
-          crs=None,
-          description=None,
+            self,
+            nodes,
+            elements,
+            boundaries=None,
+            crs=None,
+            description=None,
     ):
         self._nodes = nodes
         self._elements = elements
         super().__init__(**grd.euclidean_mesh({
-            'nodes'      : self._nodes,
-            'elements'   : self._elements,
+            'nodes': self._nodes,
+            'elements': self._elements,
             'description': description,
-            'crs'        : crs
+            'crs': crs
         }))
         self._boundaries = boundaries
 
@@ -74,26 +74,26 @@ class AdcircMesh(EuclideanMesh2D):
             msg = "Destination path exists and overwrite=False"
             raise IOError(msg)
         with fiona.open(
-              path.absolute(),
-              'w',
-              driver='ESRI Shapefile',
-              crs=self.crs.srs,
-              schema={
-                  'geometry'  : 'LineString',
-                  'properties': {
-                      'id'    : 'int',
-                      'ibtype': 'str',
-                      'bnd_id': 'str'
-                  }}) as dst:
+                path.absolute(),
+                'w',
+                driver='ESRI Shapefile',
+                crs=self.crs.srs,
+                schema={
+                    'geometry': 'LineString',
+                    'properties': {
+                        'id': 'int',
+                        'ibtype': 'str',
+                        'bnd_id': 'str'
+                    }}) as dst:
             _cnt = 0
             for ibtype, bnds in self.boundaries.items():
                 for id, bnd in bnds.items():
                     idxs = list(map(self.get_node_index, bnd['indexes']))
                     linear_ring = LineString(self.xy[idxs].tolist())
                     dst.write({
-                        "geometry"  : mapping(linear_ring),
+                        "geometry": mapping(linear_ring),
                         "properties": {
-                            "id"    : _cnt,
+                            "id": _cnt,
                             "ibtype": ibtype,
                             "bnd_id": f"{ibtype}:{id}"
                         }
@@ -101,15 +101,16 @@ class AdcircMesh(EuclideanMesh2D):
                     _cnt += 1
 
     def generate_boundaries(
-          self,
-          threshold=0.,
-          land_ibtype=0,
-          interior_ibtype=1,
+            self,
+            threshold=0.,
+            land_ibtype=0,
+            interior_ibtype=1,
     ):
         if np.any(np.isnan(self.values)):
-            raise Exception("Mesh contains invalid values. Raster values must "
-                            "be interpolated to the mesh before generating "
-                            "boundaries.")
+            msg = "Mesh contains invalid values. Raster values must "
+            msg += "be interpolated to the mesh before generating "
+            msg += "boundaries."
+            raise Exception(msg)
 
         # generate exterior boundaries
         for ring in self.outer_ring_collection.values():
@@ -164,14 +165,14 @@ class AdcircMesh(EuclideanMesh2D):
             self.set_boundary_data(interior_ibtype, bnd_id, data)
 
     def add_forcing(self, forcing, id=None):
-        if isinstance(forcing, BoundaryCondition):
+        if isinstance(forcing, _BoundaryCondition):
             if id is None:
                 for i in range(len(self.open_boundaries)):
                     self.add_forcing(forcing, i)
             else:
                 self._boundary_forcing[forcing.btype]["bnd_ids"].add(id)
                 self._boundary_forcing[forcing.btype].update({"obj": forcing})
-        elif isinstance(forcing, WindForcing):
+        elif isinstance(forcing, _WindForcing):
             self._surface_forcing.update({'imetype': forcing})
         else:
             msg = f"Unrecognized forcing type {forcing}."
@@ -193,11 +194,11 @@ class AdcircMesh(EuclideanMesh2D):
             self._nodal_attribute_collection[name] = None
 
     def set_nodal_attribute(
-          self,
-          attribute_name,
-          values,
-          coldstart: bool = False,
-          hotstart: bool = False
+            self,
+            attribute_name,
+            values,
+            coldstart: bool = False,
+            hotstart: bool = False
     ):
         if attribute_name not in self.get_nodal_attribute_names():
             raise AttributeError(f'Cannot set nodal attribute with name '
@@ -206,9 +207,9 @@ class AdcircMesh(EuclideanMesh2D):
         assert isinstance(coldstart, bool)
         assert isinstance(hotstart, bool)
         properties = {
-            'units'    : self._attributes[attribute_name]['units'],
+            'units': self._attributes[attribute_name]['units'],
             'coldstart': coldstart,
-            'hotstart' : hotstart
+            'hotstart': hotstart
         }
         self.set_attribute(attribute_name, values, **properties)
 
@@ -237,10 +238,10 @@ class AdcircMesh(EuclideanMesh2D):
         self.get_attribute(attribute)['hotstart'] = state
 
     def set_nodal_attribute_state(
-          self,
-          attribute,
-          coldstart,
-          hotstart
+            self,
+            attribute,
+            coldstart,
+            hotstart
     ):
         self.set_nodal_attribute_coldstart_state(attribute, coldstart)
         self.set_nodal_attribute_hotstart_state(attribute, hotstart)
@@ -319,14 +320,14 @@ class AdcircMesh(EuclideanMesh2D):
             self.set_nodal_attribute(attribute, full_values)
 
     def generate_tau0(
-          self,
-          default_value=0.03,
-          threshold_distance=1750.,
-          shallow_tau0=0.02,
-          deep_tau0=0.005,
-          threshold_depth=-10.,
-          coldstart=True,
-          hotstart=True
+            self,
+            default_value=0.03,
+            threshold_distance=1750.,
+            shallow_tau0=0.02,
+            deep_tau0=0.005,
+            threshold_depth=-10.,
+            coldstart=True,
+            hotstart=True
     ):
         """
         Reimplementation of tau0_gen.f by Robert Weaver (2008)
@@ -354,7 +355,7 @@ class AdcircMesh(EuclideanMesh2D):
                 else:
                     values[k] = deep_tau0
         if 'primitive_weighting_in_continuity_equation' \
-              not in self.get_nodal_attribute_names():
+                not in self.get_nodal_attribute_names():
             self.add_nodal_attribute(
                 'primitive_weighting_in_continuity_equation',
                 'unitless'
@@ -487,16 +488,16 @@ class AdcircMesh(EuclideanMesh2D):
     # plotting functions
     @fig._figure
     def make_plot(
-          self,
-          axes: pyplot.Axes = None,
-          vmin: float = None,
-          vmax: float = None,
-          show: bool = False,
-          title: str = None,
-          # figsize=rcParams["figure.figsize"],
-          extent: (float, float, float, float) = None,
-          cbar_label: str = None,
-          **kwargs
+            self,
+            axes: pyplot.Axes = None,
+            vmin: float = None,
+            vmax: float = None,
+            show: bool = False,
+            title: str = None,
+            # figsize=rcParams["figure.figsize"],
+            extent: (float, float, float, float) = None,
+            cbar_label: str = None,
+            **kwargs
     ):
         if vmin is None:
             vmin = np.min(self.values)
@@ -541,14 +542,14 @@ class AdcircMesh(EuclideanMesh2D):
 
     @fig._figure
     def plot_boundary(
-          self,
-          ibtype: str,
-          id: int,
-          tags: bool = True,
-          axes: pyplot.Axes = None,
-          show: bool = False,
-          figsize: (float, float) = None,
-          **kwargs
+            self,
+            ibtype: str,
+            id: int,
+            tags: bool = True,
+            axes: pyplot.Axes = None,
+            show: bool = False,
+            figsize: (float, float) = None,
+            **kwargs
     ):
 
         boundary = list(map(
@@ -569,11 +570,11 @@ class AdcircMesh(EuclideanMesh2D):
 
     @fig._figure
     def plot_boundaries(
-          self,
-          axes: pyplot.Axes = None,
-          show: bool = False,
-          figsize: (float, float) = None,
-          **kwargs
+            self,
+            axes: pyplot.Axes = None,
+            show: bool = False,
+            figsize: (float, float) = None,
+            **kwargs
     ):
         kwargs.update({'axes': axes})
         for ibtype, bnds in self.boundaries.items():
@@ -839,7 +840,7 @@ class AdcircMesh(EuclideanMesh2D):
 
             open_boundaries[id].update({
                 'indexes': indexes,
-                'neta'   : len(indexes),
+                'neta': len(indexes),
                 'iettype': iettype(id),
                 'ifltype': ifltype(id),
                 'itetype': itetype(id),
